@@ -3,6 +3,8 @@ __author__ = 'Lucas Theis <lucas@theis.io>'
 __docformat__ = 'epytext'
 
 from type import Type
+from list import List
 from publication import Publication
 from customlink import CustomLink
 from customfile import CustomFile
+from orderedmodel import OrderedModel
