@@ -3,17 +3,19 @@ __author__ = 'Lucas Theis <lucas@theis.io>'
 __docformat__ = 'epytext'
 
 from django.db import models
-from publication import Publication
 
 class List(models.Model):
+	"""
+	Model representing a list of publications.
+	"""
+
 	class Meta:
 		app_label = 'publications'
 		ordering = ('list',)
-		verbose_name_plural = 'Publication lists'
+		verbose_name_plural = 'Lists'
 
 	list = models.CharField(max_length=128)
 	description = models.CharField(max_length=128)
-	publications = models.ManyToManyField(Publication)
 
 	def __unicode__(self):
 		return self.list
