@@ -8,9 +8,13 @@ from django.db import models
 from django.utils.http import urlquote_plus
 from string import split, strip, join, replace, ascii_uppercase
 from publications.fields import PagesField
-from publications.models import Type
+from publications.models import Type, List
 
 class Publication(models.Model):
+	"""
+	Model representing a publication.
+	"""
+
 	class Meta:
 		app_label = 'publications'
 		ordering = ['-year', '-month', '-id']
@@ -71,12 +75,15 @@ class Publication(models.Model):
 	code = models.URLField(blank=True,
 		help_text='Link to page with code.')
 	pdf = models.FileField(upload_to='publications/', verbose_name='PDF', blank=True, null=True)
+	image = models.ImageField(upload_to='publications/images/', blank=True, null=True)
+	thumbnail = models.ImageField(upload_to='publications/thumbnails/', blank=True, null=True)
 	doi = models.CharField(max_length=128, verbose_name='DOI', blank=True)
 	external = models.BooleanField(
 		help_text='If publication was written in another lab, mark as external.')
 	abstract = models.TextField(blank=True)
 	isbn = models.CharField(max_length=32, verbose_name="ISBN", blank=True,
 		help_text='Only for a book.') # A-B-C-D
+	lists = models.ManyToManyField(List, blank=True)
 
 	def __init__(self, *args, **kwargs):
 		models.Model.__init__(self, *args, **kwargs)
