@@ -2,11 +2,13 @@ __license__ = 'MIT License <http://www.opensource.org/licenses/mit-license.php>'
 __author__ = 'Lucas Theis <lucas@theis.io>'
 __docformat__ = 'epytext'
 
-from django.template import Library, Node, Context
+import os
+
+from django.template import Library, Node, Context, RequestContext
 from django.template.loader import get_template
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
-from publications.models import Publication
+from publications.models import Publication, List
 from re import sub
 from string import replace
 
@@ -17,7 +19,7 @@ GREEK_LETTERS = \
 	'[Ee]ta|[Tt]heta|[Ll]ambda|[Mm]u|[Nn]u|[Pp]i|[Ss]igma|[Tt]au|' + \
 	'[Pp]hi|[Pp]si|[Cc]hi|[Oo]mega|[Rr]ho|[Xx]i|[Kk]appa'
 
-def get_publication(id):
+def get_publication(context, id):
 	pbl = Publication.objects.filter(pk=int(id))
 
 	if len(pbl) < 1:
@@ -27,7 +29,29 @@ def get_publication(id):
 	pbl[0].files = pbl[0].customfile_set.all()
 
 	return get_template('publications/publication.html').render(
-		Context({'publication': pbl[0]}))
+		RequestContext(context['request'], {'publication': pbl[0]}))
+
+
+def get_publication_list(context, list, template='publications/publications.html'):
+	list = List.objects.filter(list__iexact=list)
+
+	if not list:
+		return ''
+
+	list = list[0]
+	publications = list.publication_set.all()
+	publications = publications.order_by('-year', '-month', '-id')
+
+	if not publications:
+		return ''
+
+	for publication in publications:
+		publication.links = publication.customlink_set.all()
+		publication.files = publication.customfile_set.all()
+
+	return get_template(template).render(
+			RequestContext(context['request'], {'list': list, 'publications': publications}))
+
 
 def tex_parse(string):
 	string = replace(replace(string, '{', ''), '}', '')
@@ -40,5 +64,6 @@ def tex_parse(string):
 			sub(r'\\(' + GREEK_LETTERS + ')', r'&\1;', match.group(1))))))
 	return mark_safe(sub(r'\$([^\$]*)\$', tex_replace, escape(string)))
 
-register.simple_tag(get_publication)
+register.simple_tag(get_publication, takes_context=True)
+register.simple_tag(get_publication_list, takes_context=True)
 register.filter('tex_parse', tex_parse)
